summaryrefslogtreecommitdiffstats
path: root/kcoloredit/kcoloreditview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kcoloredit/kcoloreditview.h')
-rw-r--r--kcoloredit/kcoloreditview.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/kcoloredit/kcoloreditview.h b/kcoloredit/kcoloreditview.h
index ec0ca17f..0bc2a569 100644
--- a/kcoloredit/kcoloreditview.h
+++ b/kcoloredit/kcoloreditview.h
@@ -23,9 +23,9 @@
#endif
// include files for Qt
-#include <qsplitter.h>
-#include <qcheckbox.h>
-#include <qlabel.h>
+#include <tqsplitter.h>
+#include <tqcheckbox.h>
+#include <tqlabel.h>
// application specific includes
#include "colorselector.h"
@@ -34,19 +34,19 @@
class KColorEditDoc;
/** The KColorEditView class provides the view widget for the KColorEditApp instance.
* The View instance inherits QWidget as a base class and represents the view object of a KMainWindow. As KColorEditView is part of the
* docuement-view model, it needs a reference to the document object connected with it by the KColorEditApp class to manipulate and display
* the document structure provided by the KColorEditDoc class.
*
* @author Source Framework Automatically Generated by KDevelop, (c) The KDevelop Team.
* @version KDevelop version 0.4 code generation
*/
-class KColorEditView : public QSplitter {
+class KColorEditView : public TQSplitter {
Q_OBJECT
public:
/** Constructor for the main view */
- KColorEditView(QWidget *parent = 0, const char *name = 0);
+ KColorEditView(TQWidget *parent = 0, const char *name = 0);
/** Destructor for the main view */
~KColorEditView();
@@ -58,7 +58,7 @@ class KColorEditView : public QSplitter {
KColorEditDoc *document() const;
/** Contains the implementation for printing functionality */
- void print(QPrinter *pPrinter);
+ void print(TQPrinter *pPrinter);
/** Chooses a color to the color selector */
void chooseColor(Color* const color);
/** Updates the view after the document has been changed */
@@ -84,7 +84,7 @@ class KColorEditView : public QSplitter {
/** Sets whether insert or replace a color */
void slotAddColorOverwrite(bool overwrite);
/** Sets a color name */
- void slotSetColorName(const QString& name);
+ void slotSetColorName(const TQString& name);
protected:
/** Add color mode constants */
@@ -92,23 +92,23 @@ class KColorEditView : public QSplitter {
REPLACE_COLOR = 1 };
/** Color mode widget */
- QCheckBox* overwriteCheckBox;
+ TQCheckBox* overwriteCheckBox;
/** Color name widget */
- QLineEdit* colorName;
+ TQLineEdit* colorName;
/** H component value label of the color at cursor */
- QLabel* colorAtCursorHValueLabel;
+ TQLabel* colorAtCursorHValueLabel;
/** S component value label of the color at cursor */
- QLabel* colorAtCursorSValueLabel;
+ TQLabel* colorAtCursorSValueLabel;
/** V component value label of the color at cursor */
- QLabel* colorAtCursorVValueLabel;
+ TQLabel* colorAtCursorVValueLabel;
/** R component value label of the color at cursor */
- QLabel* colorAtCursorRValueLabel;
+ TQLabel* colorAtCursorRValueLabel;
/** G component value label of the color at cursor */
- QLabel* colorAtCursorGValueLabel;
+ TQLabel* colorAtCursorGValueLabel;
/** B component value label of the color at cursor */
- QLabel* colorAtCursorBValueLabel;
+ TQLabel* colorAtCursorBValueLabel;
/** RGB Hex string value label of the color at cursor */
- QLabel* colorAtCursorRgbStringValueLabel;
+ TQLabel* colorAtCursorRgbStringValueLabel;
/** If add a color at cursor */
bool addColorAtCursor;
/** Add color mode */
@@ -120,7 +120,7 @@ class KColorEditView : public QSplitter {
protected:
/** Sets component value label of the color at cursor sizes */
- void setColorAtCursorComponentValueLabelSizes(QLabel* const label);
+ void setColorAtCursorComponentValueLabelSizes(TQLabel* const label);
/** Updates color value labels */
void updateColorValueLabels();
};
@@ -34,19 +34,19 @@
class KColorEditDoc;
/** The KColorEditView class provides the view widget for the KColorEditApp instance.
- * The View instance inherits QWidget as a base class and represents the view object of a KMainWindow. As KColorEditView is part of the
+ * The View instance inherits TQWidget as a base class and represents the view object of a KMainWindow. As KColorEditView is part of the
* docuement-view model, it needs a reference to the document object connected with it by the KColorEditApp class to manipulate and display
* the document structure provided by the KColorEditDoc class.